=============
Quantum Walks
=============

.. currentmodule:: hiperwalk

Classes
-------
.. autosummary::
    :toctree: generated
    :nosignatures:

    QuantumWalk
    CoinedWalk
    ContinuousWalk

Pyneblina Interface
-------------------
Functions used to call pyneblina.
